"{ Package: 'stx:goodies/xmlsuite/core' }"

"{ NameSpace: Smalltalk }"

LibraryDefinition subclass:#stx_goodies_xmlsuite_core
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'* Projects & Packages *'
!


!stx_goodies_xmlsuite_core class methodsFor:'description'!

excludedFromPreRequisites  
    "list packages which are to be explicitely excluded from the automatic constructed
     prerequisites list. If empty, everything that is found along the inheritance of any of
     my classes is considered to be a prerequisite package."

    ^ #(
        #'stx:goodies/xmlsuite/xmlreaderimpl'
        #'stx:goodies/sunit'
        
    )

    "Modified: / 17-08-2006 / 19:48:59 / cg"
    "Created: / 20-06-2009 / 16:50:18 / Jan Vrany <vranyj1@fel.cvut.cz>"
    "Modified: / 10-01-2010 / 11:07:51 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

mandatoryPreRequisites
    "list packages which are mandatory as a prerequisite.
     This are packages containing superclasses of my classes and classes which
     are extended by myself.
     They are mandatory, because we need these packages as a prerequisite for loading and compiling.
     This method is generated automatically,
     by searching along the inheritance chain of all of my classes."

    ^ #(
        #'stx:libbasic'    "ArrayedCollection - extended"
        #'stx:libview2'    "ApplicationModel - superclass of XMLv2::DOM3Inspector"
        #'stx:libwidg2'    "AbstractHierarchicalItem - superclass of XMLv2::DOM3Inspector::DOM3NodeItem"
    )
!

referencedPreRequisites
    "list packages which are a prerequisite, because they contain
     classes which are referenced by my classes.
     We do not need these packages as a prerequisite for compiling or loading,
     however, a class from it may be referenced during execution and having it
     unloaded then may lead to a runtime doesNotUnderstand error, unless the caller
     includes explicit checks for the package being present.
     This method is generated automatically,
     by searching all classes (and their packages) which are referenced by my classes."

    ^ #(
        #'stx:libbasic2'    "Random - referenced by XMLv2::XMLGenerator>>generateAttributeValue"
        #'stx:libtool'    "InspectorView - referenced by XMLv2::DOM3Inspector>>domNodeInspectorView"
        #'stx:libview'    "Color - referenced by XMLv2::IndentingAndHighlightingXMLWriter class>>attributeValueColor"
    )
!

subProjects
    "list packages which are known as subprojects.
     The generated makefile will enter those and make there as well.
     However: they are not forced to be loaded when a package is loaded;
     for those, redefine requiredPrerequisites"

    ^ #(
    )
! !

!stx_goodies_xmlsuite_core class methodsFor:'description - compilation'!

additionalLinkLibraries_bc_dot_mak
    "allows for additional static libraries to be added to the bc.mak file.
     Subclasses may redefine this"

    "backward compatibilty with old projects"

    ^'"expat-2.0.1/bcb5/release/libexpats_mtd.lib"'

    "Created: / 09-01-2010 / 14:01:54 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

additionalLinkLibraries_make_dot_proto
    "allows for additional static libraries to be added to the make.proto file."

    ^ 'expat-2.0.1/build/lib/libexpat.a'

    "Created: / 22-08-2006 / 23:53:33 / cg"
!

additionalRules_bc_dot_mak
    "obsolete - kept for compatibility with old project files"
    
    ^ '
expat-2.0.1/bcb5/release/libexpats_mtd.lib:
        cd expat-2.0.1/bcb5
        $(MAKE)
        cd ..\..\..
'

    "Created: / 09-01-2010 / 14:03:20 / Jan Vrany <jan.vrany@fit.cvut.cz>"
    "Modified: / 22-04-2013 / 16:38:27 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

additionalRules_make_dot_proto
    "allows for additional rules to be added to the make.proto file."

    ^ '
expat-2.0.1/build/lib/libexpat.a:
        mkdir expat-2.0.1/build && cd expat-2.0.1/build && CC=$(CC) CFLAGS="$(CCCONFOPT) -fPIC" ../configure --prefix=$$PWD
        $(MAKE) -C expat-2.0.1/build
        $(MAKE) -C expat-2.0.1/build install
'

    "Created: / 22-08-2006 / 23:59:16 / cg"
    "Modified: / 22-04-2013 / 16:38:40 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

additionalTargets_bc_dot_mak
    "obsolete - kept for compatibility with old project files"
    
    ^ 'expat-2.0.1/bcb5/release/libexpats_mtd.lib'

    "Created: / 09-01-2010 / 14:02:14 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

additionalTargets_make_dot_proto
    "allows for additional targets to be added to the make.proto file."

    ^ 'expat-2.0.1/build/lib/libexpat.a'

    "Created: / 22-08-2006 / 23:53:33 / cg"
!

localIncludes
    "allow for the specification of additional include directories"

    ^ '-Iexpat-2.0.1/lib'

    "Created: / 09-01-2010 / 14:03:34 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!stx_goodies_xmlsuite_core class methodsFor:'description - contents'!

classNamesAndAttributes
    "lists the classes which are to be included in the project.
     Each entry in the list may be: a single class-name (symbol),
     or an array-literal consisting of class name and attributes.
     Attributes are: #autoload or #<os> where os is one of win32, unix,..."

    ^ #(
        "<className> or (<className> attributes...) in load order"
        #'XMLv2::AbstractSAX2Handler'
        #'XMLv2::DOM3Inspector'
        #'XMLv2::DOM3NodeDumper'
        #'XMLv2::DOMConfiguration'
        #'XMLv2::DOMError'
        #'XMLv2::DOMErrorHandler'
        #'XMLv2::DOMErrorMonitor'
        #'XMLv2::DOMImplementation'
        #'XMLv2::DOMImplementationRegistry'
        #'XMLv2::InputSource'
        #'XMLv2::NameList'
        #'XMLv2::Node'
        #'XMLv2::NodeList'
        #'XMLv2::NodeName'
        #'XMLv2::ParseError'
        #'XMLv2::Parser'
        #'XMLv2::SAXError'
        #'XMLv2::TypeInfo'
        #'XMLv2::UserDataHandler'
        #'XMLv2::XMLBuilder'
        #'XMLv2::XMLEventRecorder'
        #'XMLv2::XMLReader'
        #'XMLv2::XMLReaderImplementationQuery'
        #'XMLv2::XMLWriter'
        #'stx_goodies_xmlsuite_core'
        #'XMLv2::Attr'
        #'XMLv2::CharacterData'
        #'XMLv2::ContentHandler'
        #'XMLv2::DOM3XMLReader'
        #'XMLv2::DOMException'
        #'XMLv2::DTDHandler'
        #'XMLv2::Document'
        #'XMLv2::DocumentFragment'
        #'XMLv2::DocumentType'
        #'XMLv2::Element'
        #'XMLv2::Entity'
        #'XMLv2::EntityReference'
        #'XMLv2::EntityResolver'
        #'XMLv2::ErrorHandler'
        #'XMLv2::ExpatXMLReader'
        #'XMLv2::IndentingXMLWriter'
        #'XMLv2::NamedNodeMap'
        #'XMLv2::Notation'
        #'XMLv2::ProcessingInstruction'
        #'XMLv2::SAXParseError'
        #'XMLv2::XMLGenerator'
        #'XMLv2::XMLSuiteDOM3Implementation'
        #'XMLv2::Attributes'
        #'XMLv2::CDATASection'
        #'XMLv2::Comment'
        #'XMLv2::DOM3Builder'
        #'XMLv2::IndentingAndHighlightingXMLWriter'
        #'XMLv2::Text'
        (#'XMLv2::AbstractDOM3TestCase' autoload)
        (#'XMLv2::AbstractW3CDOM3TestCase' autoload)
        (#'XMLv2::DOM3Tests' autoload)
        (#'XMLv2::DOMBuilder' autoload)
        (#'XMLv2::EncodingTests' autoload)
        (#'XMLv2::JamesClarkCanonicalXMLWriterTestResource' autoload)
        (#'XMLv2::JamesClarkCanonicalXMLWriterTests' autoload)
        (#'XMLv2::JamesClarkXMLTests' autoload)
        (#'XMLv2::NodeNameTests' autoload)
        (#'XMLv2::OASISXMLTests' autoload)
        (#'XMLv2::W3XMLTestSuiteResource' autoload)
        (#'XMLv2::XMLBuilderTests' autoload)
        (#'XMLv2::XMLReaderTests' autoload)
        (#'XMLv2::XMLWriterTests' autoload)
        (#'XMLv2::CincomDOMXMLReader' autoload)
        (#'XMLv2::CincomImplementation' autoload)
        (#'XMLv2::JamesClarkCanonicalXMLWriter' autoload)
        (#'XMLv2::NodeTests' autoload)
        (#'XMLv2::W3CDOM3CoreTests' autoload)
        (#'XMLv2::OldXMLWriter' autoload)
        (#'XMLv2::XMLSyntaxHighlightingWriter' autoload)
    )
!

extensionMethodNames
    "list class/selector pairs of extensions.
     A correponding method with real names must be present in my concrete subclasses"

    ^ #(
        Character isInXMLCharSpec:
        Character isXMLBaseChar
        Character isXMLChar
        Character isXMLCombiningChar
        Character isXMLDigit
        Character isXMLExtender
        Character isXMLIdeographic
        Character isXMLLetter
        Character isXMLPubidChar
        Character isXMLWhiteSpace
        CharacterArray asJamesClarkCanonicalXMLEscapedString
        CharacterArray asXMLEscapedString
        Character xmlBaseCharValues
        Character xmlCombiningCharValues
        Character xmlDigitValues
        Character xmlExtenderValues
    )
! !

!stx_goodies_xmlsuite_core class methodsFor:'description - project information'!

companyName
    "Return a companyname which will appear in <lib>.rc"

    ^ 'eXept Software AG'
!

description
    "Return a description string which will appear in vc.def / bc.def"

    ^ 'Smalltalk/X Class library'
!

legalCopyright
    "Return a copyright string which will appear in <lib>.rc"

    ^ 'Copyright Claus Gittinger 1988-2008\nCopyright eXept Software AG 1998-2008'
!

productName
    "Return a product name which will appear in <lib>.rc"

    ^ 'Smalltalk/X'
! !

!stx_goodies_xmlsuite_core class methodsFor:'description - svn'!

svnRepositoryUrlString
    "Return a SVN repository URL of myself.
     (Generated since 2011-04-08)
    "        

    ^ '$URL$'
!

svnRevisionNr
    "Return a SVN revision number of myself.
     This number is updated after a commit"

    ^ "$SVN-Revision:"'287M'"$"
! !

!stx_goodies_xmlsuite_core class methodsFor:'documentation'!

version
    ^'$Id$'
!

version_HG
    ^ '$Changeset: <not expanded> $'
!

version_SVN
    ^ '$Id$'
! !

